@@ -1,8 +1,7 @@
-from unittest import TestCase
+from allpairspy import AllPairs
 
-from metacomm.combinatorics.all_pairs2 import all_pairs2 as all_pairs
 
-class TestPairwise(TestCase):
+class TestPairwise:
     def __init__(self):
         self.data = {}
     
@@ -11,7 +10,7 @@ class TestPairwise(TestCase):
         tests = [f for f in dir(self) if f.startswith('_test')]
         if not tests:
             return
-        pairwise = all_pairs([tests, self.data.keys()], filter_func = self.is_valid_combination)
+        pairwise = AllPairs([tests, list(self.data.keys())], filter_func=self.is_valid_combination)
 
         # code to make allpairs and nose play nicely with each 
         # other; maybe wrap in a nose plugin some day?
